import IIIFResource from './IIIFResource.js';
import Image from './Image.js';
/**
 * @implements IIIFResource
 */
class Canvas {
    id = '';
    type = 'sc:Canvas';
    label = '';
    images = [];
    thumbnail = {};
    /**
     * 
     * @param {string} label 
     */
    constructor(IIIFApiVersion, baseURL) {
        this.context = `http://iiif.io/api/presentation/${IIIFApiVersion}/context.json`;
        this.BASE_URL = baseURL;
    }
    /**
     * @param {string} idParam From the request
     * @param {int|string} name A unique name for this canvas
     */
    generateID(idParam, name) {
        this.id = `${this.BASE_URL}/iiif/${idParam}/canvas/${name}`;
    }
    /**
     * @param {string} label A label for this canvas
     */
    setLabel(label) {
        this.label = label;
    }
    /**
     * @param {Image} image Add an image to the canvas
     */
    addImage(image) {
        this.images.push(image.toObject());
    }
    /**
     * Add a thumbnail object
     * @todo Support multiple thumbs?
     * @param {int} [height=300]
     * @param {int} [width=300]
     */
    setThumbnail(height = 300, width = 300) {
        this.thumbnail = {
            "@id" : '',
            "@type" : 'dctypes:Image',
            height,
            width
        }
    }
    /**
     * Object representation
     */
    toObject() {
        return {
            "@context" : this.context,
            "@id" : this.id,
            "@type" : this.type,
            "label" : this.label,
            "images" : this.images,
            "thumbnail" : this.thumbnail
        }
    }
}

export default Canvas;
